<?php

namespace Drupal\component_schema\Component\Schema;

use Drupal\Core\Template\Attribute;
use Drupal\Core\TypedData\Plugin\DataType\BooleanData;

/**
 * The boolean data type with component methods.
 *
 * The plain value of a boolean is a regular PHP boolean. For setting the value
 * any PHP variable that casts to a boolean may be passed.
 */
class ComponentBooleanData extends BooleanData implements TypedComponentVariableInterface {

  use ComponentVariableTrait;

  /**
   * {@inheritdoc}
   */
  protected function addClass($value, Attribute $attribute) {
    if (!$this->getDataDefinition()->providesClass()) {
      throw new SchemaBadMethodCallException(__METHOD__ . " is not allowed on a data object that doesn't provide a class");
    }
    // Add a class if the value is TRUE.
    if ((bool) $value) {
      $provided_value = $this->getDataDefinition()->getProvidedValue();
      assert(!empty($provided_value), 'A value is set for provided_value when provides_class is true');
      if (!$attribute->hasClass($provided_value)) {
        $attribute->addClass($provided_value);
      }
    }

    return $this;
  }

  /**
   * {@inheritdoc}
   */
  protected function setAttribute($value, Attribute $attribute) {
    if (!$this->getDataDefinition()->providesAttribute()) {
      throw new SchemaBadMethodCallException(__METHOD__ . " is not allowed on a data object that doesn't provide an attribute");
    }
    // Add an attribute if the value is TRUE.
    if ((bool) $value) {
      $provided_name = $this->getDataDefinition()->getProvidedName();
      assert(!empty($provided_name), 'A value is set for provided_name when provides_attribute is true');
      $provided_value = $this->getDataDefinition()->getProvidedValue();
      assert(!empty($provided_value), 'A value is set for provided_value when provides_class is true');
      $attribute->setAttribute($provided_name, $provided_value);
    }

    return $this;
  }

}
