<?php

namespace Drupal\component_schema\Component\Schema;

use Drupal\Core\Config\Schema\Mapping;
use Drupal\Core\Template\Attribute;

/**
 * The mapping data type for components.
 */
class ComponentMapping extends Mapping implements TypedComponentVariableInterface {

  use ComponentVariableArrayElementTrait;

  /**
   * {@inheritdoc}
   */
  public function getProperties($include_computed = FALSE) {
    $properties = [];
    foreach ($this->getAllKeys() as $name) {
      $properties[$name] = $this->get($name);
    }

    return $properties;
  }

  /**
   * {@inheritdoc}
   */
  protected function getAllKeys() {
    return array_keys($this->definition['mapping'] ?? []);
  }

  /**
   * Overrides \Drupal\Core\TypedData\TypedData::setValue().
   *
   * @param array|null $values
   *   An array of property values.
   */
  public function setValue($values, $notify = TRUE) {
    if (isset($values) && !is_array($values)) {
      throw new \InvalidArgumentException("Invalid values given. Values must be represented as an associative array.");
    }

    static::initializeValue($values);
    $this->value = $values;

    // Notify the parent of any changes.
    if ($notify && isset($this->parent)) {
      $this->parent->onChange($this->name);
    }

  }

  /**
   * {@inheritdoc}
   */
  public function initializeValue(&$value, Attribute $attribute = NULL) {
    // Don't iterate the child elements if a null value is passed in.
    // Otherwise we might end up with non-empty properties, making it harder in
    // templates to skip elements that have no renderable content.
    if (!is_null($value)) {
      $elements = $this->getElements();

      // Initialize a value for the attributes field, if present.
      $attributes_element = $elements[TypedComponentVariableInterface::ATTRIBUTES_PROPERTY_NAME] ?? NULL;
      if (!is_null($attributes_element)) {
        $attribute = $value[TypedComponentVariableInterface::ATTRIBUTES_PROPERTY_NAME] ?? NULL;
        $attributes_element->initializeValue($attribute);
        $value[TypedComponentVariableInterface::ATTRIBUTES_PROPERTY_NAME] = $attribute;
      }

      $this->doInitializeValue($value, $attribute);
    }
  }

}
