<?php

namespace Drupal\component_schema\Component\Schema;

use Drupal\Core\Template\Attribute;
use Drupal\Core\TypedData\Plugin\DataType\StringData;

/**
 * The string component data type.
 *
 * The plain value of a string is a regular PHP string. For setting the value
 * any PHP variable that casts to a string may be passed.
 */
class ComponentStringData extends StringData implements TypedComponentVariableInterface {

  use ComponentVariableTrait;

  /**
   * {@inheritdoc}
   */
  public function applyDefaultValue($notify = TRUE) {
    // Apply a default if specified in the definition.
    $this
      ->setValue($this->getDataDefinition->getDefault(), $notify);
    return $this;
  }

  /**
   * Overrides \Drupal\component_schema\Component\Schema\ComponentVariableTrait::addClass()
   *
   * @param \Drupal\Core\Template\Attribute $attribute
   *   An Attribute object.
   *
   * @return $this
   */
  protected function addClass($value, Attribute $attribute) {
    if (!$this->getDataDefinition()->providesClass()) {
      throw new SchemaBadMethodCallException(__METHOD__ . " is not allowed on a data object that doesn't provide a class");
    }
    // Add a class equal to the value.
    if ($string = (string) $value) {
      if (!$attribute->hasClass($string)) {
        $attribute->addClass($string);
      }
    }

    return $this;
  }

  /**
   * {@inheritdoc}
   */
  protected function setAttribute($value, Attribute $attribute) {
    if (!$this->getDataDefinition()->providesAttribute()) {
      throw new SchemaBadMethodCallException(__METHOD__ . " is not allowed on a data object that doesn't provide an attribute");
    }
    // Add an attribute if a value is set.
    if ($value = (string) $value) {
      $provided_name = $this->getDataDefinition()->getProvidedName();
      assert(!empty($provided_name), 'A value is set for provided_name when provides_attribute is true');
      $attribute->setAttribute($provided_name, $value);
    }

    return $this;
  }

}
