<?php

namespace Drupal\component_schema\Component\Schema;

use Drupal\component_schema\Component\Schema\TypedComponentVariableInterface;
use Drupal\Core\Template\Attribute;

trait ComponentVariableArrayElementTrait {

  /**
   * Helper method to initialize array-type values.
   *
   * @param array|null $value
   *   An array of property values.
   */
  protected function doInitializeValue(&$value, Attribute $attribute = NULL) {
    if (isset($value) && !is_array($value)) {
      throw new \InvalidArgumentException("Invalid values given. Values must be represented as an associative array.");
    }

    $elements = $this->getElements();

    // Iterate through child elements.
    foreach ($elements as $name => $element) {
      // We've covered the attributes element separately.
      // @see \Drupal\component_schema\Componeent\Schema\ComponentMapping::initializeValue()
      if ($name === TypedComponentVariableInterface::ATTRIBUTES_PROPERTY_NAME) {
        continue;
      }
      $element_value = $value[$name] ?? NULL;

      // ::initializeValue() is a method of TypedComponentVariableInterface.
      if ($element instanceOf TypedComponentVariableInterface) {
        $element->initializeValue($element_value, $attribute);
      }

      $value[$name] = $element_value;
    }
  }

}
