<?php

namespace Drupal\component_schema\Component\Schema;

use Drupal\Core\TypedData\DataDefinitionInterface;

/**
 * Interface for typed component variable data definitions.
 */
interface ComponentVariableDataDefinitionInterface extends DataDefinitionInterface {

  /**
   * Determines whether the specified data object provides a class attribute.
   *
   * @return bool
   *   Whether or not the data object provides a class attribute (TRUE if
   *   provides).
   */
  public function providesClass();

  /**
   * Determines whether the specified data object provides an HTML attribute.
   *
   * @return bool
   *   Whether or not the data object provides an HTML attribute (TRUE if
   *   provides).
   */
  public function providesAttribute();

  /**
   * Gets the provided name for a variable attribute.
   *
   * @return string|NULL
   *   The provided name or NULL if none.
   */
  public function getProvidedName();

  /**
   * Gets the provided value for a class or attribute.
   *
   * @return string|NULL
   *   The provided value or NULL if none.
   */
  public function getProvidedValue();

  /**
   * Determines whether the specified data object supports breakpoints.
   *
   * @return bool
   *   Whether or not the data object supports breakpoints (TRUE if supports).
   */
  public function supportsBreakpoints();

  /**
   * Gets the URL of a page with documentation on the variable.
   *
   * @return string|NULL
   *   The URL value or NULL if none.
   */
  public function getDocumentationUrl();

  /**
   * Gets the default value for a variable.
   *
   * @return string|NULL
   *   The default value or NULL if none.
   */
  public function getDefault();

}
