<?php

namespace Drupal\component_schema\Component\Schema;

use Drupal\component_schema\Component\Schema\TypedComponentVariableInterface;
use Drupal\Core\Template\Attribute;

trait ComponentVariableTrait {

  /**
   * Adds classes or merges them on to array of existing CSS classes.
   *
   * @param \Drupal\Core\Template\Attribute $attribute
   *   An Attribute object.
   *
   * @return $this
   */
  protected abstract function addClass();

  /**
   * Sets values for an HTML attribute.
   *
   * @param \Drupal\Core\Template\Attribute $attribute
   *   An Attribute object.
   *
   * @return $this   * @param \Drupal\Core\Template\Attribute $attribute
   *   An Attribute object.
   */
  protected abstract function setAttribute();

  /**
   * Overrides \Drupal\Core\TypedData\TypedData::setValue().
   *
   * @param array|null $values
   *   An array of property values.
   */
  public function initializeValue(&$value, Attribute $attribute = NULL) {
    // Set a default value.
    if (empty($value)) {
      $value = $this->getDataDefinition()->getDefault();
    }

    // Provide a class.
    if ($this->getDataDefinition()->providesClass()) {
      $this->addClass($value, $attribute);
    }
    // Provide an attribute.
    if ($this->getDataDefinition()->providesAttribute()) {
      $this->setAttribute($value, $attribute);
    }
  }

}
